package
module
Version:
v0.0.0-...-7ba6fb3
Opens a new window with list of versions in this module.
Published: Feb 20, 2022
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Sentinel
Simple package for creating sentinel errors in Golang
Usage:
package mypackage
const ErrorSomethingWentWrong = sentinel.Error("something went wrong")
func myFunc() error {
// ...
if somethingWentWrong {
return ErrorSomethingWentWrong
}
// ...
}
Documentation
¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.